/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package com.ebmwebsourcing.jbi.adaptor.impl;

import javax.jbi.messaging.MessageExchange;
import javax.jbi.messaging.NormalizedMessage;
import javax.xml.transform.TransformerException;

import org.ow2.petals.commons.log.FlowAttributesExchangeHelper;
import org.ow2.petals.component.api.Message;

import com.ebmwebsourcing.easycommons.lang.UncheckedException;
import com.ebmwebsourcing.easycommons.xml.SourceHelper;

/**
 * @author Marc Jambert - EBM WebSourcing
 */
public abstract class AbstractWrappedMessage implements Message {

    protected MessageExchange messageExchange;
    
    public AbstractWrappedMessage(MessageExchange messageExchange) {
       this.messageExchange = messageExchange;
    }
    
    @Override
    public String getFlowStepInterfaceName() {
        return String.valueOf(this.messageExchange.getInterfaceName());
    }

    @Override
    public String getFlowStepServiceName() {
        return String.valueOf(this.messageExchange.getEndpoint().getServiceName());
    }

    @Override
    public String getFlowStepOperationName() {
        return String.valueOf(this.messageExchange.getOperation());
    }

    @Override
    public String getFlowStepEndpointName() {
        return this.messageExchange.getEndpoint().getEndpointName();
    }

    @Override
    public String getFlowStepId() {
        return FlowAttributesExchangeHelper.getFlowAttributes(this.messageExchange).getFlowStepId();
    }
    
    public MessageExchange getMessageExchange() {
        return this.messageExchange;
    }
    
	protected final String getPayload(String messageName) {
		NormalizedMessage message = messageExchange.getMessage(messageName);
		assert message != null;
		try {
            return SourceHelper.toString(message.getContent());
		} catch (TransformerException te) {
			throw new UncheckedException(te);
		}
	}
    
}
