/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package com.ebmwebsourcing.jbi.adaptor.impl;

import java.io.InputStream;
import java.net.URI;

import javax.jbi.messaging.ExchangeStatus;
import javax.jbi.messaging.MessageExchange.Role;
import javax.jbi.messaging.MessagingException;
import javax.jbi.messaging.NormalizedMessage;
import javax.xml.namespace.QName;
import javax.xml.transform.stream.StreamSource;

import org.ow2.petals.commons.log.FlowAttributes;
import org.ow2.petals.component.api.ServiceConfiguration;
import org.ow2.petals.component.framework.api.message.Exchange;

import com.ebmwebsourcing.easycommons.lang.UncheckedException;

/**
 * @author Marc Jambert - EBM WebSourcing
 */
public class WrappedStatusFromConsumerMessage extends AbstractWrappedToComponentMessage {

    public WrappedStatusFromConsumerMessage(ServiceConfiguration serviceConfiguration, QName operation, URI mep,
            InputStream outMessageContentStream, FlowAttributes flowAttributes, ExchangeStatus status) {
        super(serviceConfiguration, operation, mep, flowAttributes);
        
        try {   
            setRole(Role.PROVIDER);
            NormalizedMessage outNm = this.messageExchange.createMessage();
            outNm.setContent(new StreamSource(outMessageContentStream));
            this.messageExchange.setMessage(outNm, Exchange.OUT_MESSAGE_NAME);
            closeExchangeAsConsumer(status);
        } catch (MessagingException e) {
            throw new UncheckedException("Impossible to create a message exchange", e);
        }
    }
    
    private void closeExchangeAsConsumer(ExchangeStatus status) throws MessagingException {
        setRole(Role.CONSUMER);
        closeExchange(status);
        setRole(Role.PROVIDER);
    }

    private void closeExchange(ExchangeStatus status) throws MessagingException {
        this.messageExchange.setStatus(status);
    }
    
    @Override
    public String getPayload() {
    	throw new UnsupportedOperationException();
    }
}
