/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package com.ebmwebsourcing.jbi.adaptor.impl.mock;

import java.util.MissingResourceException;
import java.util.Vector;
import java.util.logging.Logger;

import javax.jbi.JBIException;
import javax.jbi.component.ComponentContext;
import javax.jbi.management.MBeanNames;
import javax.jbi.messaging.DeliveryChannel;
import javax.jbi.messaging.MessagingException;
import javax.jbi.servicedesc.ServiceEndpoint;
import javax.management.MBeanServer;
import javax.naming.InitialContext;
import javax.xml.namespace.QName;

import org.mockito.Mockito;
import org.ow2.petals.component.framework.AbstractComponent;
import org.w3c.dom.Document;
import org.w3c.dom.DocumentFragment;

/**
 * @author Adrien Ruffie - EBM WebSourcing
 */
public class MockComponentContext implements ComponentContext {

    private final String installRoot;

    private final String workspaceRoot;

    private final Logger logger;

    private final MockDeliveryChannel deliveryChannel;

    private final MBeanServer mockMBeanServer;

    private final MBeanNames mockMBeanNames;

    private final String componentName;

    private static Vector<MockServiceEndpoint> serviceEndpoints = new Vector<MockServiceEndpoint>();

    private final AbstractComponent jbiComponent;

    public MockComponentContext(String componentName, AbstractComponent jbiComponent,
            String installRoot, String workspaceRoot, Logger logger) {
        this.componentName = componentName;
        this.installRoot = installRoot;
        this.workspaceRoot = workspaceRoot;
        this.jbiComponent = jbiComponent;
        this.logger = logger;
        this.deliveryChannel = new MockDeliveryChannel(logger);
        this.mockMBeanServer = Mockito.mock(MBeanServer.class);
        this.mockMBeanNames = Mockito.mock(MBeanNames.class);

    }

    @Override
    public ServiceEndpoint activateEndpoint(QName serviceName, String endpointName)
            throws JBIException {
        MockServiceEndpoint mockServiceEndpoint = new MockServiceEndpoint(endpointName, serviceName);
        Document description = this.jbiComponent.getServiceDescription(mockServiceEndpoint);
        mockServiceEndpoint.setDescription(description);
        serviceEndpoints.add(mockServiceEndpoint);
        return mockServiceEndpoint;
    }

    @Override
    public void deactivateEndpoint(ServiceEndpoint endpoint) throws JBIException {
        serviceEndpoints.remove(endpoint);
    }

    @Override
    public void deregisterExternalEndpoint(ServiceEndpoint externalEndpoint) throws JBIException {
        // TODO Auto-generated method stub
    }

    @Override
    public String getComponentName() {
        return this.componentName;
    }

    @Override
    public DeliveryChannel getDeliveryChannel() throws MessagingException {
        return this.deliveryChannel;
    }

    @Override
    public ServiceEndpoint getEndpoint(QName service, String name) {
        return resolveServiceEndpoint(service, name);
    }

    private MockServiceEndpoint resolveServiceEndpoint(QName service, String name) {
        MockServiceEndpoint result = null;

        for (MockServiceEndpoint serviceEndpoint : serviceEndpoints) {
            if (name.equals(serviceEndpoint.getEndpointName())
                    && service.equals(serviceEndpoint.getServiceName())) {
                result = serviceEndpoint;
                break;
            }
        }

        return result;
    }

    public static ServiceEndpoint resolveServiceEndpoint(QName service) {
        ServiceEndpoint result = null;

        // try to resolve with service name only, get the first ep for this
        // service
        for (ServiceEndpoint serviceEndpoint : serviceEndpoints) {
            if (service.equals(serviceEndpoint.getServiceName())) {
                result = serviceEndpoint;
                break;
            }
        }

        return result;
    }

    @Override
    public Document getEndpointDescriptor(ServiceEndpoint endpoint) throws JBIException {
        MockServiceEndpoint mockServiceEnpoint = resolveServiceEndpoint(endpoint.getServiceName(),
                endpoint.getEndpointName());
        Document description = mockServiceEnpoint.getDescription();
        return description;
    }

    @Override
    public ServiceEndpoint[] getEndpoints(QName interfaceName) {
        // TODO Auto-generated method stub
        return null;
    }

    @Override
    public ServiceEndpoint[] getEndpointsForService(QName serviceName) {
        // TODO Auto-generated method stub
        return null;
    }

    @Override
    public ServiceEndpoint[] getExternalEndpoints(QName interfaceName) {
        // TODO Auto-generated method stub
        return null;
    }

    @Override
    public ServiceEndpoint[] getExternalEndpointsForService(QName serviceName) {
        // TODO Auto-generated method stub
        return null;
    }

    @Override
    public String getInstallRoot() {
        return this.installRoot;
    }

    @Override
    public Logger getLogger(String suffix, String resourceBundleName)
            throws MissingResourceException, JBIException {
        return this.logger;
    }

    @Override
    public MBeanNames getMBeanNames() {
        return this.mockMBeanNames;
    }

    @Override
    public MBeanServer getMBeanServer() {
        return this.mockMBeanServer;
    }

    @Override
    public InitialContext getNamingContext() {
        // TODO Auto-generated method stub
        return null;
    }

    @Override
    public Object getTransactionManager() {
        // TODO Auto-generated method stub
        return null;
    }

    @Override
    public String getWorkspaceRoot() {
        return workspaceRoot;
    }

    @Override
    public void registerExternalEndpoint(ServiceEndpoint externalEndpoint) throws JBIException {
        // TODO Auto-generated method stub

    }

    @Override
    public ServiceEndpoint resolveEndpointReference(DocumentFragment epr) {
        // TODO Auto-generated method stub
        return null;
    }
}
