/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package com.ebmwebsourcing.jbi.adaptor.impl.mock;

import java.io.File;
import java.util.List;

import javax.jbi.component.ComponentContext;
import javax.jbi.component.InstallationContext;

import org.ow2.petals.component.framework.jbidescriptor.generated.Jbi;
import org.w3c.dom.DocumentFragment;

/**
 * @author Adrien Ruffie - EBM WebSourcing
 */
public class MockInstallationContext implements InstallationContext {

    private final File installationRoot;

    private final Jbi jbi;

    private final ComponentContext componentContext;

    private final boolean isInstallContext;

    /**
     * 
     * @param installationRoot
     * @param jbi
     * @param componentContext
     * @param isInstallContext
     *            <code>true</code> if the {@link InstallationContext} is an
     *            installation context, <code>false</code> if the
     *            {@link InstallationContext} is an uninstallation context.
     */
    public MockInstallationContext(File installationRoot, Jbi jbi, ComponentContext componentContext, final boolean isInstallContext) {
        this.installationRoot = installationRoot;
        this.jbi = jbi;
        this.componentContext = componentContext;
        this.isInstallContext = isInstallContext;
    }

    @Override
    public List getClassPathElements() {
        throw new UnsupportedOperationException();
    }

    @Override
    public String getComponentClassName() {
        return jbi.getComponent().getComponentClassName().getContent();
    }

    @Override
    public String getComponentName() {
        return jbi.getComponent().getIdentification().getName();
    }

    @Override
    public ComponentContext getContext() {
        return componentContext;
    }

    @Override
    public DocumentFragment getInstallationDescriptorExtension() {
        throw new UnsupportedOperationException();
    }

    @Override
    public String getInstallRoot() {
        return installationRoot.getAbsolutePath();
    }

    @Override
    public boolean isInstall() {
        return this.isInstallContext;
    }

    @Override
    public void setClassPathElements(List classPathElements) {
        throw new UnsupportedOperationException();
    }

}
